pub struct MockTimer;Expand description
A mocked version of embassy_time::Timer that can be used in its place for unit tests.
This mocked version just immediately returns Poll::Ready when await’ed on.
Examples
use embassy_futures::block_on;
use embassy_mock::time::{MockTimer, Timer};
use embassy_time::Duration;
let timer = MockTimer::after(Duration::from_secs(1));
block_on(timer);Trait Implementations
impl Eq for MockTimer
impl StructuralPartialEq for MockTimer
Sourceimpl Timer for MockTimer
impl Timer for MockTimer
Sourcefn after(_duration: Duration) -> Self
fn after(_duration: Duration) -> Self
Create a MockTimer that can be used to unit test code.
Examples
use embassy_mock::time::Timer;
use embassy_time::Duration;
async fn production_code<T: Timer>() {
// Do something...
T::after(Duration::from_millis(100)).await;
// Do something else...
}
// The unit tests that use the `MockTimer`
#[cfg(test)]
mod tests {
use super::*;
use embassy_futures::block_on;
use embassy_mock::time::MockTimer;
#[test]
fn test_creating_timer() {
block_on(production_code::<MockTimer>());
}
}Auto Trait Implementations
impl Freeze for MockTimer
impl RefUnwindSafe for MockTimer
impl Send for MockTimer
impl Sync for MockTimer
impl Unpin for MockTimer
impl UnsafeUnpin for MockTimer
impl UnwindSafe for MockTimer